@@ -217,7 +217,11 @@ public:
 
 protected:
     void componentComplete() override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#else
+    void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#endif
 
 private:
     const QScopedPointer<IconLabelLayoutPrivate> d_ptr;
